@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from pathlib import Path
+from textwrap import dedent
 from unittest import mock
 
 import pytest
@@ -78,6 +79,15 @@ def test_on_pdm_install_setup_pre_commit_success(project: Project) -> None:
     action_mock.execute.assert_called_once()
 
 
+def assert_output(out: str, expected: str):
+    __tracebackhide__ = True
+
+    # Invisible whitespace enfinf lines (table side effect)
+    out = "\n".join(line.rstrip() for line in out.splitlines())
+
+    assert out.strip() == dedent(expected).strip()
+
+
 def test_pdm_printer_list_success(capsys: pytest.CaptureFixture[str]) -> None:
     printer = PDMPrinter(UI())
 
@@ -91,7 +101,7 @@ def test_pdm_printer_list_success(capsys: pytest.CaptureFixture[str]) -> None:
     )
     captured = capsys.readouterr()
 
-    assert "[sync-pre-commit-lock]  ✔ https://repo1.local/test   rev1 -> rev2" in captured.out
+    assert_output(captured.out, "[sync-pre-commit-lock]  ✔ https://repo1.local/test   rev1 -> rev2")
 
 
 def test_pdm_printer_list_success_additional_dependency(capsys: pytest.CaptureFixture[str]) -> None:
@@ -107,9 +117,12 @@ def test_pdm_printer_list_success_additional_dependency(capsys: pytest.CaptureFi
     )
     captured = capsys.readouterr()
 
-    assert "[sync-pre-commit-lock]  ✔ https://repo1.local/test" in captured.out
-    assert "[sync-pre-commit-lock]    └ hook" in captured.out
-    assert "[sync-pre-commit-lock]      └ dep                    * -> 0.1.2" in captured.out
+    expected = """
+    [sync-pre-commit-lock]  ✔ https://repo1.local/test
+    [sync-pre-commit-lock]    └ hook
+    [sync-pre-commit-lock]      └ dep                    * -> 0.1.2
+    """
+    assert_output(captured.out, expected)
 
 
 def test_pdm_printer_list_success_repo_with_multiple_hooks_and_additional_dependency(
@@ -141,12 +154,15 @@ def test_pdm_printer_list_success_repo_with_multiple_hooks_and_additional_depend
     )
     captured = capsys.readouterr()
 
-    assert "[sync-pre-commit-lock]  ✔ https://repo1.local/test   rev1   -> rev2" in captured.out
-    assert "[sync-pre-commit-lock]    ├ 1st-hook" in captured.out
-    assert "[sync-pre-commit-lock]    │ └ other                  0.42   -> 3.4.5" in captured.out
-    assert "[sync-pre-commit-lock]    └ 2nd-hook" in captured.out
-    assert "[sync-pre-commit-lock]      ├ dep                    *      -> 0.1.2" in captured.out
-    assert "[sync-pre-commit-lock]      └ other                  >=0.42 -> 3.4.5" in captured.out
+    expected = """
+    [sync-pre-commit-lock]  ✔ https://repo1.local/test   rev1   -> rev2
+    [sync-pre-commit-lock]    ├ 1st-hook
+    [sync-pre-commit-lock]    │ └ other                  0.42   -> 3.4.5
+    [sync-pre-commit-lock]    └ 2nd-hook
+    [sync-pre-commit-lock]      ├ dep                    *      -> 0.1.2
+    [sync-pre-commit-lock]      └ other                  >=0.42 -> 3.4.5
+    """
+    assert_output(captured.out, expected)
 
 
 def test_pdm_printer_list_success_renamed_repository(capsys: pytest.CaptureFixture[str]) -> None:
@@ -162,4 +178,4 @@ def test_pdm_printer_list_success_renamed_repository(capsys: pytest.CaptureFixtu
     )
     captured = capsys.readouterr()
 
-    assert "[sync-pre-commit-lock]  ✔ https://{old -> new}.repo.local/test   rev1 -> rev2" in captured.out
+    assert_output(captured.out, "[sync-pre-commit-lock]  ✔ https://{old -> new}.repo.local/test   rev1 -> rev2")
